@@ -42,7 +42,8 @@ from cctrl.output import print_deployment_details, print_app_details,\
     print_worker_list, print_worker_details, print_cronjob_list, \
     print_cronjob_details, print_addon_creds, print_config
 from output import print_user_list_app, print_user_list_deployment
-from cctrl.addonoptionhelpers import parse_additional_addon_options, parse_config_variables
+from cctrl.addonoptionhelpers import parse_additional_addon_options, \
+    parse_config_variables, extract_flag_from_variables
 
 
 class AppsController():
@@ -738,8 +739,11 @@ class AppController():
         if not args.variables:
             raise InputErrorException('NoVariablesGiven')
 
-        variables = parse_config_variables(args.variables, 'add')
-        force = args.force_add
+        args_variables, force = extract_flag_from_variables(args.variables,
+                                                            ('-f', '--force'),
+                                                            args.force_add)
+
+        variables = parse_config_variables(args_variables, 'add')
 
         try:
             self.api.update_addon(
@@ -926,9 +930,15 @@ class AppController():
 
     def addUser(self, args):
         """
-            Add a user specified by the e-mail address to an application.
+            Add a user specified by the e-mail address to an application or deployment.
         """
         app_name, deployment_name = self.parse_app_deployment_name(args.name)
+
+        if self.settings.prefix_project_name:
+            if len(args.email.split(':')) != 2:
+                prefix = self.api.read_users()[0]['email'].split(':')[0]
+                args.email = '{}:{}'.format(prefix, args.email)
+
         try:
             if deployment_name:
                 self.api.create_deployment_user(app_name, deployment_name, args.email, args.role)
@@ -944,7 +954,7 @@ class AppController():
 
     def removeUser(self, args):
         """
-            Remove a user specified by the user name or email address from an application.
+            Remove a user specified by the user name or email address from an application or deployment.
         """
         app_name, deployment_name = self.parse_app_deployment_name(args.name)
         if '@' in args.username:
